==> widelands_1.2.1.orig.tar.gz: widelands-1.2.1/data/tribes/buildings/productionsites/frisians/aqua_farm/init.lua <==
push_textdomain("tribes")

local dirname = path.dirname(__file__)

wl.Descriptions():new_productionsite_type {
   name = "frisians_aqua_farm",
   -- TRANSLATORS: This is a building name used in lists of buildings
   descname = pgettext("frisians_building", "Aqua Farm"),
   animation_directory = dirname,
   icon = dirname .. "menu.png",
   size = "small",

   buildcost = {
      brick = 2,
      log = 1,
      reed = 1
   },
   return_on_dismantle = {
      brick = 1,
      log = 1
   },

   spritesheets = {
      idle = {
         hotspot = {40, 71},
         frames = 10,
         columns = 5,
         rows = 2,
         fps = 10
      }
   },
   animations = {
      unoccupied = {
         hotspot = {40, 53}
      }
   },

   aihints = {
      prohibited_till = 760,
      requires_supporters = true
   },

   working_positions = {
      frisians_fisher = 1
   },

   inputs = {
      { name = "water", amount = 5 },
      { name = "fruit", amount = 2 },
   },

   programs = {
      main = {
         -- TRANSLATORS: Completed/Skipped/Did not start working because ...
         descname = _("working"),
         actions = {
            "call=breed_fish",
            "call=fish_pond",
         },
      },
      breed_fish = {
         -- TRANSLATORS: Completed/Skipped/Did not start breeding fish because ...
         descname = _("breeding fish"),
         actions = {
            "return=skipped unless economy needs fish",
            "return=failed unless site has water:2",
            "return=failed unless site has fruit",
            "callworker=breed_in_pond",
            "consume=fruit water:2",
            "sleep=duration:23s",
         },
      },
      fish_pond = {
         -- TRANSLATORS: Completed/Skipped/Did not start fishing because ...
         descname = _("fishing"),
         actions = {
            "return=skipped unless economy needs fish",
            "sleep=duration:9s",
            "callworker=fish_in_pond",
         },
      },
      encyclopedia = {
         -- just a dummy program to fix encyclopedia
         descname = "encyclopedia",
         actions = {
            "consume=fruit water:2",
            "produce=fish",
         },
      },
   },

   out_of_resource_notification = {
      -- Translators: Short for "Out of ..." for a resource
      title = _("No Ponds"),
      heading = _("Out of Fish Ponds"),
      message = pgettext ("frisians_building", "The fisher working at this aqua farm can’t find any fish ponds in his work area. Please make sure there is a working clay pit nearby and the aqua farm is supplied with all needed wares, or consider dismantling or destroying this building."),
      productivity_threshold = 12
   },
}

pop_textdomain()

==> widelands-1.3.1.tar.gz: widelands-1.3.1/data/tribes/buildings/productionsites/frisians/aqua_farm/init.lua <==
push_textdomain("tribes")

local dirname = path.dirname(__file__)

wl.Descriptions():new_productionsite_type {
   name = "frisians_aqua_farm",
   -- TRANSLATORS: This is a building name used in lists of buildings
   descname = pgettext("frisians_building", "Aqua Farm"),
   animation_directory = dirname,
   icon = dirname .. "menu.png",
   size = "small",

   buildcost = {
      brick = 2,
      log = 1,
      reed = 1
   },
   return_on_dismantle = {
      brick = 1,
      log = 1
   },

   spritesheets = {
      idle = {
         hotspot = {40, 71},
         frames = 10,
         columns = 5,
         rows = 2,
         fps = 10
      },
      build = {
         hotspot = {40, 53},
         frames = 3,
         columns = 3,
         rows = 1,
      }
   },
   animations = {
      unoccupied = {
         hotspot = {40, 53}
      }
   },

   aihints = {
      prohibited_till = 760,
      requires_supporters = true
   },

   working_positions = {
      frisians_fisher = 1
   },

   inputs = {
      { name = "water", amount = 5 },
      { name = "fruit", amount = 2 },
   },

   programs = {
      main = {
         -- TRANSLATORS: Completed/Skipped/Did not start working because ...
         descname = _("working"),
         actions = {
            -- min. time total: 32.2 + 19.2 =  51.4 sec
            -- max. time total: 64.6 + 51.6 = 116.2 sec
            "call=breed_fish",
            "call=fish_pond",
         },
      },
      breed_fish = {
         -- TRANSLATORS: Completed/Skipped/Did not start breeding fish because ...
         descname = _("breeding fish"),
         actions = {
            -- time of worker: 9.2-41.6 sec
            -- min. time: 9.2  + 23 = 32.2 sec
            -- max. time: 41.6 + 23 = 64.6 sec
            "return=skipped unless economy needs fish",
            "return=failed unless site has water:2",
            "return=failed unless site has fruit",
            "callworker=breed_in_pond",
            "consume=fruit water:2",
            "sleep=duration:23s",
         },
      },
      fish_pond = {
         -- TRANSLATORS: Completed/Skipped/Did not start fishing because ...
         descname = _("fishing"),
         actions = {
            -- time of worker: 10.2-42.6 sec
            -- min. time: 9 + 10.2 = 19.2 sec
            -- max. time: 9 + 42.6 = 51.6 sec
            "return=skipped unless economy needs fish",
            "sleep=duration:9s",
            "callworker=fish_in_pond",
         },
      },
      encyclopedia = {
         -- just a dummy program to fix encyclopedia
         descname = "encyclopedia",
         actions = {
            "consume=fruit water:2",
            "produce=fish",
         },
      },
   },

   out_of_resource_notification = {
      -- Translators: Short for "Out of ..." for a resource
      title = _("No Ponds"),
      heading = _("Out of Fish Ponds"),
      message = pgettext ("frisians_building", "The fisher working at this aqua farm can’t find any fish ponds in his work area. Please make sure there is a working clay pit nearby and the aqua farm is supplied with all needed wares, or consider dismantling or destroying this building."),
      productivity_threshold = 12
   },
}

pop_textdomain()
